/*
*   Tabla para almacenar los datos de las universidades
*/
-- Tabla
CREATE TABLE universidad (
    id NUMBER(3),
    nombre VARCHAR2(50) CONSTRAINT AK_university_name UNIQUE CONSTRAINT NN_university_name NOT NULL,
    direccion VARCHAR2(200) CONSTRAINT NN_university_addr NOT NULL,
    web VARCHAR2(100)
);
-- Comentarios
COMMENT ON TABLE universidad IS 'Tabla con los datos de las universidades registradas en el sistema.';
COMMENT ON COLUMN universidad.id IS 'Identificador autonumérico (clave sintética) de cada universidad.';
COMMENT ON COLUMN universidad.nombre IS 'Nombre de la universidad.';
COMMENT ON COLUMN universidad.direccion IS 'Dirección de la sede principal de la universidad.';
COMMENT ON COLUMN universidad.web IS 'URL con la web pública de la universidad.';

/*
*   Tabla para almacenar los datos de las distintas titulaciones
*/
-- Tabla
CREATE TABLE titulacion (
    codigo VARCHAR2(10),
    nombre VARCHAR2(150) CONSTRAINT NN_titulation_name NOT NULL
);
-- Comentarios
COMMENT ON TABLE titulacion IS 'Tabla con los datos de las titulaciones que se imparten en las universidades registradas en el sistema.';
COMMENT ON COLUMN titulacion.codigo IS 'Código unico identificativo de cada titulación.';
COMMENT ON COLUMN titulacion.nombre IS 'Nombe de la titulación.';

/*
*   Tabla para almacenar los datos de los profesores responsables
*/
-- Tabla
CREATE TABLE profesor_responsable (
    universidad_id NUMBER(3),
    id NUMBER(3),
    nombre VARCHAR2(50) CONSTRAINT NN_professor_name NOT NULL,
    apellido1 VARCHAR2(50) CONSTRAINT NN_professor_surname NOT NULL,
    apellido2 VARCHAR2(50)
);
-- Comentarios
COMMENT ON TABLE profesor_responsable IS 'Tabla con los datos de los profesores responsables de las prácticas de los alumnos.';
COMMENT ON COLUMN profesor_responsable.universidad_id IS 'Identificador de la universidad a la que pertenece el profesor.';
COMMENT ON COLUMN profesor_responsable.id IS 'Identificador autonumérico (clave sintética) del profesor dentro de la universidad.';
COMMENT ON COLUMN profesor_responsable.nombre IS 'Nombe del profesor.';
COMMENT ON COLUMN profesor_responsable.apellido1 IS 'Primer apellido del profesor.';
COMMENT ON COLUMN profesor_responsable.apellido2 IS 'Segundo apellido del profesor (opcional).';

/*
*   Tabla para almacenar los datos de los estudiantes
*/
-- Tabla
CREATE TABLE estudiante (
    universidad_id NUMBER(3),
    id NUMBER(3),
    nombre VARCHAR2(50) CONSTRAINT NN_estudiante_name NOT NULL,
    apellido1 VARCHAR2(50) CONSTRAINT NN_estudiante_surname NOT NULL,
    apellido2 VARCHAR2(50)
);
-- Comentarios
COMMENT ON TABLE estudiante IS 'Tabla con los datos de los estudiantes universitarios interesados en las prácticas.';
COMMENT ON COLUMN estudiante.universidad_id IS 'Identificador de la universidad a la que pertenece el estudiante.';
COMMENT ON COLUMN estudiante.id IS 'Identificador autonumérico (clave sintética) del estudiante dentro de la universidad.';
COMMENT ON COLUMN estudiante.nombre IS 'Nombe del estudiante.';
COMMENT ON COLUMN estudiante.apellido1 IS 'Primer apellido del estudiante.';
COMMENT ON COLUMN estudiante.apellido2 IS 'Segundo apellido del estudiante (opcional).';

/*
*   Tabla para almacenar la relación entre estudiantes, universidades, titulaciones y profesores
*/
-- Tabla
CREATE TABLE cursa (
    universidad_id NUMBER(3),
    titulacion_id VARCHAR2(10),
    profesor_id NUMBER(3),
    estudiante_id NUMBER(3),
    anyo_acad VARCHAR2(5) CONSTRAINT NN_cursa_anyo NOT NULL
);
-- Comentarios
COMMENT ON TABLE cursa IS 'Tabla con los datos de la relación entre estudiantes, universidades, titulaciones y profesores (estudios cursados).';
COMMENT ON COLUMN cursa.universidad_id IS 'Identificador de la universidad en la que se cursan los estudios.';
COMMENT ON COLUMN cursa.titulacion_id IS 'Identificador de la titulación cursada.';
COMMENT ON COLUMN cursa.profesor_id IS 'Identificador del profesor que supervisará las prácticas del estudiante.';
COMMENT ON COLUMN cursa.estudiante_id IS 'Identificador del estudiante que cursa los estudios.';
COMMENT ON COLUMN cursa.anyo_acad IS 'Año académico en el que se están cursando los estudios.';

/*
*   Tabla con los datos de las empresas que ofrecen plazas
*/
-- Tabla
CREATE TABLE empresa (
    id NUMBER(3),
    cif VARCHAR2(10) CONSTRAINT AK_empresa_cif UNIQUE CONSTRAINT NN_empresa_cif NOT NULL,
    nombre VARCHAR2(50) CONSTRAINT NN_empresa_nombre NOT NULL,
    direccion VARCHAR2(200) CONSTRAINT NN_empresa_direccion NOT NULL,
    telefono VARCHAR2(15) CONSTRAINT NN_empresa_telefono NOT NULL,
    responsable_rrhh VARCHAR2(200) CONSTRAINT NN_empresa_responsable_rrhh NOT NULL
);
-- Comentarios
COMMENT ON TABLE empresa IS 'Tabla con los datos de las empresas que ofrecen plazas.';
COMMENT ON COLUMN empresa.id IS 'Identificador autonumérico (clave sintética) de cada empresa.';
COMMENT ON COLUMN empresa.cif IS 'Código de identificación fiscal de la empresa.';
COMMENT ON COLUMN empresa.nombre IS 'Nombre de la empresa.';
COMMENT ON COLUMN empresa.direccion IS 'Domicilio de la sede de la empresa.';
COMMENT ON COLUMN empresa.telefono IS 'Número de teléfono de contacto con la empresa.';
COMMENT ON COLUMN empresa.responsable_rrhh IS 'Datos (nombre y apellidos) de la persona responsable de las prácticas en RRHH.';

/*
*   Tabla con los datos de las inspecciones realizadas a las empresas
*/
-- Tabla
CREATE TABLE inspeccion (
    id NUMBER(5),
    empresa_id NUMBER(3) CONSTRAINT NN_inspeccion_empresa NOT NULL,
    fecha DATE CONSTRAINT NN_inspeccion_fecha NOT NULL,
    muestreos VARCHAR2(4000) CONSTRAINT NN_inspeccion_muestreos NOT NULL
);
-- Comentarios
COMMENT ON TABLE inspeccion IS 'Tabla con los datos de las inspecciones realizadas a las empresas.';
COMMENT ON COLUMN inspeccion.id IS 'Identificador autonumérico (clave sintética) de cada inspección.';
COMMENT ON COLUMN inspeccion.empresa_id IS 'Empresa a la que se le ha realizado la inspección.';
COMMENT ON COLUMN inspeccion.fecha IS 'Fecha de la inspección.';
COMMENT ON COLUMN inspeccion.muestreos IS 'Muestreos realizados durante la inspección.';

/*
*   Tabla con los datos de las personas solicitantes dentro de las empresas
*/
CREATE TABLE solicitante (
    empresa_id NUMBER(3),
    id NUMBER(3),
    nombre VARCHAR2(200) CONSTRAINT NN_solicitante_nombre NOT NULL,
    cargo VARCHAR2(50) CONSTRAINT NN_solicitante_cargo NOT NULL
);
-- Comentarios
COMMENT ON TABLE solicitante IS 'Tabla con los datos de las personas solicitantes dentro de las empresas.';
COMMENT ON COLUMN solicitante.empresa_id IS 'Empresa a la que pertenece la persona solicitante.';
COMMENT ON COLUMN solicitante.id IS 'Identificador autonumérico (clave sintética) de cada solicitante.';
COMMENT ON COLUMN solicitante.nombre IS 'Nombre completo de la persona solicitante.';
COMMENT ON COLUMN solicitante.cargo IS 'Cargo que ocupa la persona solicitante en la empresa.';

/*
*   Tabla con los datos de las ofertas presentadas a las universidades
*/
CREATE TABLE oferta (
    id NUMBER(5),
    empresa_id NUMBER(3) CONSTRAINT NN_oferta_idempresa NOT NULL,
    solicitante_id NUMBER(3) CONSTRAINT NN_oferta_idsolicitante NOT NULL,
    descripcion VARCHAR2(1000) CONSTRAINT NN_oferta_descripcion NOT NULL,
    requisitos VARCHAR2(1000),
    anyo_acad VARCHAR2(5) CONSTRAINT NN_oferta_anyo_acad NOT NULL,
    plazas NUMBER(2) CONSTRAINT NN_oferta_plazas NOT NULL
);
-- Comentarios
COMMENT ON TABLE oferta IS 'Tabla con los datos de las ofertas presentadas a las universidades.';
COMMENT ON COLUMN oferta.id IS 'Identificador autonumérico (clave sintética) de cada oferta.';
COMMENT ON COLUMN oferta.empresa_id IS 'Empresa a la que pertenece la persona solicitante de esta oferta.';
COMMENT ON COLUMN oferta.solicitante_id IS 'Identificador de la persona solicitante.';
COMMENT ON COLUMN oferta.descripcion IS 'Descripción de la oferta presentada.';
COMMENT ON COLUMN oferta.requisitos IS 'Requisitos de la oferta (si los tuviera).';
COMMENT ON COLUMN oferta.anyo_acad IS 'Curso académico en el que se realiza la oferta.';
COMMENT ON COLUMN oferta.plazas IS 'Número de plazas de la oferta.';

/*
*   Tabla con la recepción de las ofertas por parte de las universidades
*/
CREATE TABLE recibe (
    universidad_id NUMBER(3),
    oferta_id NUMBER(5)
);
-- Comentarios
COMMENT ON TABLE recibe IS 'Tabla con la recepción de las ofertas por parte de las universidades.';
COMMENT ON COLUMN recibe.universidad_id IS 'Universidad que recibe la oferta.';
COMMENT ON COLUMN recibe.oferta_id IS 'Oferta recibida por la universidad.';

/*
*   Tabla con las candidaturas presentadas a las ofertas disponibles
*/
CREATE TABLE candidatura (
    universidad_id NUMBER(3),
    estudiante_id NUMBER(3),
    oferta_id NUMBER(5),
    fecha DATE CONSTRAINT NN_candidatura_fecha NOT NULL
);
-- Comentarios
COMMENT ON TABLE candidatura IS 'Tabla con las candidaturas presentadas a las ofertas disponibles.';
COMMENT ON COLUMN candidatura.universidad_id IS 'Universidad a la que pertenece el estudiante que se presenta.';
COMMENT ON COLUMN candidatura.estudiante_id IS 'Estudiante que se presenta a la oferta.';
COMMENT ON COLUMN candidatura.oferta_id IS 'Oferta a la que se presenta.';
COMMENT ON COLUMN candidatura.fecha IS 'Fecha en la que se presenta la candidatura.';

/*
*   Tabla con las entrevistas realizadas entre un estudiante candidato y la persona solicitante de la empresa
*/
CREATE TABLE entrevista (
    universidad_id NUMBER(3),
    estudiante_id NUMBER(3),
    oferta_id NUMBER(5),
    empresa_id NUMBER(3),
    solicitante_id NUMBER(3),
    fecha DATE CONSTRAINT NN_entrevista_fecha NOT NULL,
    comentarios VARCHAR2(2000),
    es_apto CHAR CONSTRAINT NN_entrevista_es_apto NOT NULL CONSTRAINT CHK_entrevista_es_apto CHECK (es_apto IN (0, 1))
);
-- Comentarios
COMMENT ON TABLE entrevista IS 'Tabla con las entrevistas realizadas entre un estudiante candidato y la persona solicitante de la empresa.';
COMMENT ON COLUMN entrevista.universidad_id IS 'Universidad a la que pertenece la persona candidata.';
COMMENT ON COLUMN entrevista.estudiante_id IS 'Persona candidata que realiza la entrevista.';
COMMENT ON COLUMN entrevista.oferta_id IS 'Oferta a la que referencia la entrevista.';
COMMENT ON COLUMN entrevista.empresa_id IS 'Empresa en la que trabaja la persoa solicitante';
COMMENT ON COLUMN entrevista.solicitante_id IS 'Persona solicitane que realiza la entrevista.';
COMMENT ON COLUMN entrevista.fecha IS 'Fecha en la que se realiza la entrevista.';
COMMENT ON COLUMN entrevista.comentarios IS 'Comentarios que registra la persona entrevistadora.';
COMMENT ON COLUMN entrevista.es_apto IS 'Resultado de si la persona candidata es apta.';

/*
*   Tabla con las colaboraciones firmadas entre las empresas y las personas estudiantes
*/
CREATE TABLE colaboracion (
    empresa_id NUMBER(3),
    universidad_id NUMBER(3),
    estudiante_id NUMBER(3),
    oferta_id NUMBER(5),
    fecha_inicio DATE CONSTRAINT NN_colaboracion_fecha_inicio NOT NULL,
    fecha_final DATE CONSTRAINT NN_colaboracion_fecha_final NOT NULL,
    sueldo NUMBER(5),
    informes_esperados NUMBER(2) CONSTRAINT NN_colaboracion_informes_esperados NOT NULL
 );
-- Comentarios
COMMENT ON TABLE colaboracion IS 'Tabla con las colaboraciones firmadas entre las empresas y las personas estudiantes.';
COMMENT ON COLUMN colaboracion.empresa_id IS 'Empresa con la que se formaliza la colaboración.';
COMMENT ON COLUMN colaboracion.universidad_id IS 'Universidad a la que pertenece la persona que firma la colaboración.';
COMMENT ON COLUMN colaboracion.estudiante_id IS 'Persona que formaliza la colaboración.';
COMMENT ON COLUMN colaboracion.oferta_id IS 'Oferta respecto a la que se formaliza la colaboración.';
COMMENT ON COLUMN colaboracion.fecha_inicio IS 'Fecha de inicio de la colaboración.';
COMMENT ON COLUMN colaboracion.fecha_final IS 'Fecha final de la colaboración.';
COMMENT ON COLUMN colaboracion.sueldo IS 'Sueldo (si se establece) de la colaboración.';
COMMENT ON COLUMN colaboracion.informes_esperados IS 'Número de informes que la empresa deberá presentar durante la colaboración.';

/*
*   Tabla con los informes que presentan las empresas sobre las personas que realizan las prácticas
*/
CREATE TABLE informe (
    empresa_id NUMBER(3),
    universidad_id NUMBER(3),
    estudiante_id NUMBER(3),
    oferta_id NUMBER(5),
    solicitante_id NUMBER(3),
    fecha DATE,
    comentarios VARCHAR2(4000) CONSTRAINT NN_informe_comentarios NOT NULL
);
-- Comentarios
COMMENT ON TABLE informe IS 'Tabla con los informes que presentan las empresas sobre las personas que realizan las prácticas.';
COMMENT ON COLUMN informe.empresa_id IS 'Empresa en la que se están realizando las prácticas a las que se refiere el informe.';
COMMENT ON COLUMN informe.universidad_id IS 'Universidad a la que pertenece la persona estudiante a la que se refiere el informe.';
COMMENT ON COLUMN informe.estudiante_id IS 'Persona estudiante a la que se refiere el informe.';
COMMENT ON COLUMN informe.oferta_id IS 'Oferta respecto a la que se estableció la colaboración a la que se refiere el informe.';
COMMENT ON COLUMN informe.solicitante_id IS 'Persona que realiza el informe por parte de la empresa.';
COMMENT ON COLUMN informe.fecha IS 'Fecha en la que se realiza el informe.';
COMMENT ON COLUMN informe.comentarios IS 'Comentarios realizados en el informe.';

/*
*   Tabla con los datos de los informes de tipo final
*/
CREATE TABLE informe_final (
    empresa_id NUMBER(3),
    universidad_id NUMBER(3),
    estudiante_id NUMBER(3),
    oferta_id NUMBER(5),
    solicitante_id NUMBER(3),
    fecha DATE,
    valoracion VARCHAR2(4000) CONSTRAINT NN_final_valoracion NOT NULL,
    es_apto CHAR CONSTRAINT NN_final_es_apto NOT NULL CONSTRAINT CHK_final_es_apto CHECK (es_apto IN (0, 1))
);
-- Comentarios
COMMENT ON TABLE informe_final IS 'Tabla con los datos de los informes de tipo final.';
COMMENT ON COLUMN informe_final.empresa_id IS 'Empresa en la que se están realizando las prácticas a las que se refiere el informe.';
COMMENT ON COLUMN informe_final.universidad_id IS 'Universidad a la que pertenece la persona estudiante a la que se refiere el informe.';
COMMENT ON COLUMN informe_final.estudiante_id IS 'Persona estudiante a la que se refiere el informe.';
COMMENT ON COLUMN informe_final.oferta_id IS 'Oferta respecto a la que se estableció la colaboración a la que se refiere el informe.';
COMMENT ON COLUMN informe_final.solicitante_id IS 'Persona que realiza el informe por parte de la empresa.';
COMMENT ON COLUMN informe_final.fecha IS 'Fecha en la que se realiza el informe.';
COMMENT ON COLUMN informe_final.valoracion IS 'Valoración final de las prácticas.';
COMMENT ON COLUMN informe_final.es_apto IS 'Resultado de aptitud de las prácticas.';

/*
*   Tabla con los valores para el cálculo estadístico de las empresas
*/
CREATE TABLE re_empresas (
    id NUMBER(3),
    num_intrvws NUMBER(3) CONSTRAINT NN_RE_emp_n_intrvws NOT NULL,
    num_plazas NUMBER(3) CONSTRAINT NN_RE_emp_n_plazas NOT NULL,
    inspecciones NUMBER(3) CONSTRAINT NN_RE_emp_inspecciones NOT NULL,
    plazas_any_anterior NUMBER(3) CONSTRAINT NN_RE_emp_plzs_a_ant NOT NULL,
    plazas_any_actual NUMBER(3) CONSTRAINT NN_RE_emp_plzs_a_act NOT NULL
);
-- Comentarios
COMMENT ON TABLE re_empresas IS 'Tabla con los valores para el cálculo estadístico de las empresas.';
COMMENT ON COLUMN re_empresas.id IS 'Identificador de la empresa en la tabla principal.';
COMMENT ON COLUMN re_empresas.num_intrvws IS 'Número de entrevistas realizadas por la empresa.';
COMMENT ON COLUMN re_empresas.num_plazas IS 'Número de plazas ofertadas por la empresa.';
COMMENT ON COLUMN re_empresas.inspecciones IS 'Número de inspecciones que ha recibido la empresa.';
COMMENT ON COLUMN re_empresas.plazas_any_anterior IS 'Número de plazas ofertadas por la empresa el año anterior.';
COMMENT ON COLUMN re_empresas.plazas_any_actual IS 'Número de plazas ofertadas por la empresa en el año actual.';

/*
*   Tabla con los valores para el cálculo estadístico de las universidades
*/
CREATE TABLE re_universidades (
    id NUMBER(3),
    stdnts_en_pract NUMBER(3) CONSTRAINT NN_RE_univ_std_pract NOT NULL,
    stdnts_superan NUMBER(3) CONSTRAINT NN_RE_univ_std_superan NOT NULL,
    prcnt_stdnts_sup NUMBER(5, 2) CONSTRAINT NN_RE_univ_pct_std_sup NOT NULL
);
-- Comentarios
COMMENT ON TABLE re_universidades IS 'Tabla con los valores para el cálculo estadístico de las universidades.';
COMMENT ON COLUMN re_universidades.id IS 'Identificador de la universidad en la tabla principal.';
COMMENT ON COLUMN re_universidades.stdnts_en_pract IS 'Número de estudiantes de la universidad en prácticas.';
COMMENT ON COLUMN re_universidades.stdnts_superan IS 'Número de estudiantes que superan las prácticas.';
COMMENT ON COLUMN re_universidades.prcnt_stdnts_sup IS 'Porcentaje de estudiantes que han superado las prácticas.';

/*
*   Tabla con los valores para el cálculo estadístico de los profesores
*/
CREATE TABLE re_profesores (
    id NUMBER(3),
    num_students NUMBER(3) CONSTRAINT NN_RE_prof_n_stdnts NOT NULL
);
-- Comentarios
COMMENT ON TABLE re_profesores IS 'Tabla con los valores para el cálculo estadístico de los profesores.';
COMMENT ON COLUMN re_profesores.id IS 'Identificador del profesor en la tabla principal.';
COMMENT ON COLUMN re_profesores.num_students IS 'Número de estudiantes en prácticas que dirige el profesor.';

/*
*   Tabla con los valores para el cálculo estadístico de las titulaciones
*/
CREATE TABLE re_titulaciones (
    codigo VARCHAR2(10),
    estudiantes_aptos NUMBER(3) CONSTRAINT NN_RE_tit_n_aptos NOT NULL
);
-- Comentarios
COMMENT ON TABLE re_titulaciones IS 'Tabla con los valores para el cálculo estadístico de las titulaciones.';
COMMENT ON COLUMN re_titulaciones.codigo IS 'Identificador de la titulación en la tabla principal.';
COMMENT ON COLUMN re_titulaciones.estudiantes_aptos IS 'Número de estudiantes aptos de dicha titulación.';

/*
*    Tabla con los valores calculados por año universitario
*/
CREATE TABLE re_any_univ (
    anyo_univ VARCHAR2(5),
    total_students NUMBER(3) CONSTRAINT NN_RE_total_students NOT NULL,
    no_superan NUMBER(3) CONSTRAINT NN_RE_no_superan NOT NULL,
    prcnt_no_superan NUMBER(5, 2) CONSTRAINT NN_RE_prcnt_no_superan NOT NULL,
    max_num_intrvws NUMBER(3) CONSTRAINT NN_RE_max_num_intrvws NOT NULL,
	empresa_max_intrvws_id NUMBER(3),
    empresa_max_intrvws VARCHAR2(50)
);
-- Comentarios
COMMENT ON TABLE re_any_univ IS 'Tabla con los valores calculados con rango temporal del año universitario.';
COMMENT ON COLUMN re_any_univ.anyo_univ IS 'Año universitario al que pertenecen el resto de valores.';
COMMENT ON COLUMN re_any_univ.total_students IS 'Número total de estudiantes, de cualquier universidad que han realizado prácticas en empresas.';
COMMENT ON COLUMN re_any_univ.no_superan IS 'Número total de estudiantes, de cualquier universidad, que no han superado las prácticas.';
COMMENT ON COLUMN re_any_univ.prcnt_no_superan IS 'Porcentaje de estudiantes, de cualquier universidad, que no superan las prácticas en empresas.';
COMMENT ON COLUMN re_any_univ.max_num_intrvws IS 'Número de entrevistas de la empresa que más ha realizado en un año universitario concreto.';
COMMENT ON COLUMN re_any_univ.empresa_max_intrvws_id IS 'Id de la empresa que, en un año en concreto, ha realizado el mayor número de entrevistas.';
COMMENT ON COLUMN re_any_univ.empresa_max_intrvws IS 'Empresa que, en un año en concreto, ha realizado el mayor número de entrevistas.';

/*
*    Tabla con los valores calculados en el año actual
*/
CREATE TABLE re_any_actual (
    suma_sueldos NUMBER(8) CONSTRAINT NN_RE_suma_sueldos NOT NULL,
    num_muestras NUMBER(3) CONSTRAINT NN_RE_num_muestras NOT NULL,
    sueldo_medio NUMBER(5) CONSTRAINT NN_RE_sueldo_medio NOT NULL,
    num_estudiantes_actual NUMBER(3) CONSTRAINT NN_RE_num_estudiantes_actual NOT NULL,
    total_universidades NUMBER(3) CONSTRAINT NN_RE_total_universidades NOT NULL,
    num_univ_no_stdnts NUMBER(3) CONSTRAINT NN_RE_num_univ_no_stdnts NOT NULL,
    prcnt_no_stdnts NUMBER(5, 2) CONSTRAINT NN_RE_prcnt_no_stdnts NOT NULL,
    total_candidatos NUMBER(5) CONSTRAINT NN_RE_total_candidatos NOT NULL,
    num_ofertas NUMBER(3) CONSTRAINT NN_RE_num_ofertas NOT NULL,
    media_candidat_ofert NUMBER(5, 2) CONSTRAINT NN_RE_media_candidat_ofert NOT NULL,
    max_num_stdnts_prof NUMBER(2) CONSTRAINT NN_RE_max_num_stdnts_prof NOT NULL,
    profesor_max_stdnts_id NUMBER(3),
    profesor_max_stdnts VARCHAR2(153)
);
-- Comentarios
COMMENT ON TABLE re_any_actual IS 'Tabla con los valores calculados con rango termporal del año actual.';
COMMENT ON COLUMN re_any_actual.suma_sueldos IS 'Sumatorio de todos los sueldos de las personas en prácticas.';
COMMENT ON COLUMN re_any_actual.num_muestras IS 'Número de personas sobre las que se han sumado los sueldos.';
COMMENT ON COLUMN re_any_actual.sueldo_medio IS 'Sueldo medio que reciben los estudiantes durante sus prácticas.';
COMMENT ON COLUMN re_any_actual.num_estudiantes_actual IS 'Número total de estudiantes en prácticas en el momento de ejecutar la consulta.';
COMMENT ON COLUMN re_any_actual.total_universidades IS 'Número de universidades controladas por el CIC,';
COMMENT ON COLUMN re_any_actual.num_univ_no_stdnts IS 'Número de universidades que no tienen estudiantes.';
COMMENT ON COLUMN re_any_actual.prcnt_no_stdnts IS 'Porcentaje de universidades controladas por el CIC que no tienen estudiantes en prácticas.';
COMMENT ON COLUMN re_any_actual.total_candidatos IS 'Número total de personas que se han presentado a ofertas.';
COMMENT ON COLUMN re_any_actual.num_ofertas IS 'Número de ofertas disponibles.';
COMMENT ON COLUMN re_any_actual.media_candidat_ofert IS 'Número medio de estudiantes que se presentan a cada oferta recibida por las diferentes universidades durante el año universitario en curso.';
COMMENT ON COLUMN re_any_actual.max_num_stdnts_prof IS 'Número máximo de estudiantes que dirige un profesor';
COMMENT ON COLUMN re_any_actual.profesor_max_stdnts_id IS 'En el año uniersitario en curso, id del profesor que lleva un mayor número de estudiantes que están realizando prácticas en empresas.';
COMMENT ON COLUMN re_any_actual.profesor_max_stdnts IS 'En el año uniersitario en curso, profesor que lleva un mayor número de estudiantes que están realizando prácticas en empresas.';

/*
*    Tabla con los valores calculados en todo el tiempo
*/
CREATE TABLE re_general (
    max_prcnt_stdnts_superan NUMBER(5, 2) CONSTRAINT NN_RE_max_prcnt_stdnts_superan NOT NULL,
    univ_max_stdnts_sup_id NUMBER(3),
    univ_max_stdnts_sup VARCHAR2(50),
    empresas_mas_plazas_id VARCHAR2(23),
    empresas_mas_plazas VARCHAR2(258),
    max_inspecciones NUMBER(3) CONSTRAINT NN_RE_max_inspecciones NOT NULL,
    empresa_mas_inspecciones_id NUMBER(3),
    empresa_mas_inspecciones VARCHAR2(50),
    total_duracion_contratos NUMBER(7, 1) CONSTRAINT NN_RE_total_duracion_contratos NOT NULL,
    num_contratos NUMBER(6) CONSTRAINT NN_RE_num_contratos NOT NULL,
    duracion_media_contrato NUMBER(3, 1) CONSTRAINT NN_RE_duracion_media_contrato NOT NULL,
    num_informes_pendents NUMBER(5) CONSTRAINT NN_RE_num_informes_pendents NOT NULL,
    prcnt_emp_no_plazas_any_act NUMBER(5, 2) CONSTRAINT NN_RE_prcnt_emp_no_plazas NOT NULL,
    max_stdnts_aptos NUMBER(5) CONSTRAINT NN_RE_max_stdnts_aptos NOT NULL,
    titulacion_id VARCHAR2(10),
    titulacion VARCHAR2(150)
);
-- Comentarios
COMMENT ON TABLE re_general IS 'Tabla con los valores calculados con rango ilimitado';
COMMENT ON COLUMN re_general.max_prcnt_stdnts_superan IS 'Porcentaje más alto de estudiantes que superan las prácticas de entre todas las universidades.';
COMMENT ON COLUMN re_general.univ_max_stdnts_sup_id IS 'Universidad(ID) que tiene un porcentaje más alto de estudiantes que superan las prácticas en empresas.';
COMMENT ON COLUMN re_general.univ_max_stdnts_sup IS 'Universidad que tiene un porcentaje más alto de estudiantes que superan las prácticas en empresas.';
COMMENT ON COLUMN re_general.empresas_mas_plazas_id IS 'Top5 de empresas (IDs) que han ofrecido más plazas para estudiantes en prácticas al CIC.';
COMMENT ON COLUMN re_general.empresas_mas_plazas IS 'Top5 de empresas que han ofrecido más plazas para estudiantes en prácticas al CIC.';
COMMENT ON COLUMN re_general.max_inspecciones IS 'Número máximo de inspecciones que han tenido entre todas las empresas.';
COMMENT ON COLUMN re_general.empresa_mas_inspecciones_id IS 'Empresa (ID) que ha recibido más inspecciones de trabajo.';
COMMENT ON COLUMN re_general.empresa_mas_inspecciones IS 'Empresa que ha recibido más inspecciones de trabajo.';
COMMENT ON COLUMN re_general.total_duracion_contratos IS 'Sumatorio con la duración en meses de todos los contratos de los que se tienen datos.';
COMMENT ON COLUMN re_general.num_contratos IS 'Número total de contratos de los que se tienen datos.';
COMMENT ON COLUMN re_general.duracion_media_contrato IS 'Duración media de los contratos de estudiantes con las empresas.';
COMMENT ON COLUMN re_general.num_informes_pendents IS 'Número total de informes de prácticas pendientes de ser realizados por las personas responsables de las empresas.';
COMMENT ON COLUMN re_general.prcnt_emp_no_plazas_any_act IS 'Porcentaje de empresas que ofrecieron plazas el año anterior y no las han ofrecido en el actual.';
COMMENT ON COLUMN re_general.max_stdnts_aptos IS 'Número máximo de estudiantes de una titulación que han superado las prácticas.';
COMMENT ON COLUMN re_general.titulacion_id IS 'Titulación universitaria (ID) con un mayor número de estudiantes que han acabado satisfactoriamente las prácticas en empresas.';
COMMENT ON COLUMN re_general.titulacion IS 'Titulación universitaria con un mayor número de estudiantes que han acabado satisfactoriamente las prácticas en empresas.';

/*
*	Tabla con los logs de las operaciones ejecutadas en el sistema y sus resultados
*/
CREATE TABLE logs (
    fecha DATE CONSTRAINT NN_logs_fecha NOT NULL,
    usuario VARCHAR2(100) CONSTRAINT NN_logs_usuario NOT NULL,
    operacion VARCHAR2(50) CONSTRAINT NN_logs_operacion NOT NULL,
    parametros VARCHAR2(4000) CONSTRAINT NN_logs_parametros NOT NULL,
    resultado VARCHAR2(1000) CONSTRAINT NN_logs_resultado NOT NULL
);
-- Comentarios
COMMENT ON TABLE logs IS 'Tabla con los logs de las operaciones ejecutadas en el sistema y sus resultados';
COMMENT ON COLUMN logs.fecha IS 'Fecha y hora de la operación ejecutada.';
COMMENT ON COLUMN logs.usuario IS 'Usuario del sistema que ejecuta la operación.';
COMMENT ON COLUMN logs.operacion IS 'Nombre de la operación ejecutada.';
COMMENT ON COLUMN logs.parametros IS 'Parámetros utilizados en la ejecución.';
COMMENT ON COLUMN logs.resultado IS 'Resultado de la operación.';

/*
*	Tabla con los logs de las excepciones producidas en las operaciones del respositorio estadístico
*/
CREATE TABLE logs_dw (
    fecha DATE CONSTRAINT NN_logs_dw_fecha NOT NULL,
    usuario VARCHAR2(100) CONSTRAINT NN_logs_dw_usuario NOT NULL,
    operacion VARCHAR2(50) CONSTRAINT NN_logs_dw_operacion NOT NULL,
    parametros VARCHAR2(4000) CONSTRAINT NN_logs_dw_parametros NOT NULL,
    resultado VARCHAR2(1000) CONSTRAINT NN_logs_dw_resultado NOT NULL
);
-- Comentarios
COMMENT ON TABLE logs_dw IS 'Tabla con los logs de las excepciones producidas en las operaciones del respositorio estadístico';
COMMENT ON COLUMN logs_dw.fecha IS 'Fecha y hora de la operación ejecutada.';
COMMENT ON COLUMN logs_dw.usuario IS 'Usuario del sistema que ejecuta la operación.';
COMMENT ON COLUMN logs_dw.operacion IS 'Nombre de la operación ejecutada.';
COMMENT ON COLUMN logs_dw.parametros IS 'Parámetros utilizados en la ejecución.';
COMMENT ON COLUMN logs_dw.resultado IS 'Resultado de la operación.';
